/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.notifications.service;

import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.ObjectWriter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import se.vgregion.usdservice.USDService;
import se.vgregion.usdservice.domain.Issue;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Patrik Bergström
 */
@Service
class UsdIssuesService {

    private static final Logger LOGGER = LoggerFactory.getLogger(UsdIssuesService.class);

    private USDService usdService;

    public UsdIssuesService() {
    }

    @Autowired
    public UsdIssuesService(USDService usdService) {
        this.usdService = usdService;
    }


    public String getUsdIssuesJson(String userId) {

        List<Issue> issues = usdService.lookupIssues(userId, -1, true);

        ObjectWriter writer = new ObjectMapper().writerWithDefaultPrettyPrinter();
        try {
            return writer.writeValueAsString(issues);
        } catch (IOException e) {
            LOGGER.error(e.getMessage(), e);
            return "Internt fel.";
        }
    }

    // The cachedResult is used by NotificationsCacheAspect
    public List<Issue> getUsdIssues(String userId, boolean cachedResult) {
        List<Issue> issues = usdService.lookupIssues(userId, -1, true);
        if (issues == null) {
            return new ArrayList<Issue>();
        }
        return issues;
    }

    public String getBopsId(String userId) {
        return usdService.getBopsId(userId);
    }
}
